@@ -2,9 +2,10 @@
 # See LICENSE file for licensing details.
 
 
-from Auts import Auts
 from pydantic import BaseModel
-from Rand import Rand
+
+from fiveg_core_common_schemas.Auts import Auts
+from fiveg_core_common_schemas.Rand import Rand
 
 
 class ResynchronizationInfo(BaseModel):
