@@ -2,10 +2,11 @@
 # See LICENSE file for licensing details.
 
 
-from Ipv4Addr import Ipv4Addr
-from Ipv6Addr import Ipv6Addr
 from pydantic import BaseModel
-from TraceDepth import TraceDepth
+
+from fiveg_core_common_schemas.Ipv4Addr import Ipv4Addr
+from fiveg_core_common_schemas.Ipv6Addr import Ipv6Addr
+from fiveg_core_common_schemas.TraceDepth import TraceDepth
 
 
 class TraceData(BaseModel):
